summaryrefslogtreecommitdiffstatshomepage
path: root/src/osd/modules/input/input_sdlcommon.cpp
diff options
context:
space:
mode:
author therealmogminer@gmail.com <therealmogminer@gmail.com>2016-04-17 19:15:58 +0200
committer therealmogminer@gmail.com <therealmogminer@gmail.com>2016-04-17 19:16:14 +0200
commit250a5cc805a41409cbd6b8a1bfcb33e002e3f6f0 (patch)
treeb767b65a8ccc667bd22a70f8f2fadead6f72b206 /src/osd/modules/input/input_sdlcommon.cpp
parent9d8c3cb34178347bb1751da2d6f496a935fa35a6 (diff)
Add AVI writing to bgfx, nw
Diffstat (limited to 'src/osd/modules/input/input_sdlcommon.cpp')
-rw-r--r--src/osd/modules/input/input_sdlcommon.cpp9
1 files changed, 8 insertions, 1 deletions
diff --git a/src/osd/modules/input/input_sdlcommon.cpp b/src/osd/modules/input/input_sdlcommon.cpp
index 0f6116fa048..10d9f7b3b52 100644
--- a/src/osd/modules/input/input_sdlcommon.cpp
+++ b/src/osd/modules/input/input_sdlcommon.cpp
@@ -233,7 +233,14 @@ void sdl_osd_interface::customize_input_type_list(simple_list<input_type_entry>
entry.configure_osd("INCREASE_PRESCALE", "Increase Prescaling");
entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F7, KEYCODE_LCONTROL);
break;
- // add a Not lcrtl condition to the load state key
+
+ // lshift-lalt-F12 for fullscreen video (BGFX)
+ case IPT_OSD_8:
+ entry.configure_osd("RENDER_AVI", "Record Rendered Video");
+ entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F12, KEYCODE_LSHIFT, KEYCODE_LALT);
+ break;
+
+ // add a Not lcrtl condition to the load state key
case IPT_UI_LOAD_STATE:
entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F7, input_seq::not_code, KEYCODE_LCONTROL, input_seq::not_code, KEYCODE_LSHIFT);
break;